==> bitcoin-23.0.tar.gz: bitcoin-23.0/src/qt/locale/bitcoin_mr_IN.ts <==
<TS version="2.1" language="mr_IN">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">पत्ता किंवा लेबल संपादित करण्यासाठी उजवे बटण क्लिक करा.</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">एक नवीन पत्ता तयार करा</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;नवा</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation type="unfinished">सध्याचा निवडलेला पत्ता सिस्टीम क्लिपबोर्डावर कॉपी करा</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp;कॉपी</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">&amp;बंद करा</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">सध्याचा निवडलेला पत्ता यादीमधून काढून टाका</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">शोधण्यासाठी पत्ता किंवा लेबल दाखल करा</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">सध्याच्या टॅबमधील डेटा एका फाईलमध्ये एक्स्पोर्ट करा</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;एक्स्पोर्ट</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">&amp;काढून टाका</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">ज्या पत्त्यावर नाणी पाठवायची आहेत तो निवडा</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">ज्या पत्त्यावर नाणी प्राप्त करायची आहेत तो</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">&amp;निवडा</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation type="unfinished">प्रेषक पत्ते</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation type="unfinished">स्वीकृती पत्ते</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">पैसे पाठविण्यासाठीचे हे तुमचे बिटकॉईन पत्त्ते आहेत. नाणी पाठविण्यापूर्वी नेहमी रक्कम आणि प्राप्त होणारा पत्ता तपासून पहा.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">&amp;पत्ता कॉपी करा</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">शिक्का कॉपी करा</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;संपादित</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">पत्त्याची निर्यात करा</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">निर्यात अयशस्वी</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">लेबल</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">पत्ता</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(लेबल नाही)</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(लेबल नाही)</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">पत्ता</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">लेबल</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(लेबल नाही)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(लेबल नाही)</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">लेबल</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(लेबल नाही)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">लेबल</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">पत्ता</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">निर्यात अयशस्वी</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;एक्स्पोर्ट</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">सध्याच्या टॅबमधील डेटा एका फाईलमध्ये एक्स्पोर्ट करा</translation>
    </message>
    </context>
</TS>

==> bitcoin-25.0.tar.gz: bitcoin-25.0/src/qt/locale/bitcoin_mr_IN.ts <==
<TS version="2.1" language="mr_IN">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">पत्ता किंवा लेबल संपादित करण्यासाठी उजवे बटण क्लिक करा.</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">एक नवीन पत्ता तयार करा</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;नवा</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation type="unfinished">सध्याचा निवडलेला पत्ता सिस्टीम क्लिपबोर्डावर कॉपी करा</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp;कॉपी</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">&amp;बंद करा</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">सध्याचा निवडलेला पत्ता यादीमधून काढून टाका</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">शोधण्यासाठी पत्ता किंवा लेबल दाखल करा</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">सध्याच्या टॅबमधील डेटा एका फाईलमध्ये एक्स्पोर्ट करा</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;एक्स्पोर्ट</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">&amp;काढून टाका</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">ज्या पत्त्यावर नाणी पाठवायची आहेत तो निवडा</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">ज्या पत्त्यावर नाणी प्राप्त करायची आहेत तो</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">&amp;निवडा</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation type="unfinished">प्रेषक पत्ते</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation type="unfinished">स्वीकृती पत्ते</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">पैसे पाठविण्यासाठीचे हे तुमचे बिटकॉईन पत्त्ते आहेत. नाणी पाठविण्यापूर्वी नेहमी रक्कम आणि प्राप्त होणारा पत्ता तपासून पहा.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">&amp;पत्ता कॉपी करा</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">शिक्का कॉपी करा</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;संपादित</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">पत्त्याची निर्यात करा</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">कॉमा सेपरेटेड फ़ाइल</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <extracomment>An error message. %1 is a stand-in argument for the name of the file we attempted to save to.</extracomment>
        <translation type="unfinished">पत्ता सूची  वर जतन करण्याचा प्रयत्न करताना त्रुटी आली. कृपया पुन्हा प्रयत्न करा.%1</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">निर्यात अयशस्वी</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">लेबल</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">पत्ता</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(लेबल नाही)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation type="unfinished">पासफ़्रेज़ डाएलोग</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation type="unfinished">पासफ़्रेज़  प्रविष्ट करा</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation type="unfinished">नवीन पासफ़्रेज़ </translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation type="unfinished">नवीन पासफ़्रेज़  पुनरावृत्ती करा</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation type="unfinished">पासफ़्रेज़ दाखवा</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation type="unfinished">वॉलेट एनक्रिप्ट करा</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation type="unfinished">वॉलेट अनलॉक करण्यासाठी या ऑपरेशनला तुमच्या वॉलेट पासफ़्रेज़ची आवश्यकता आहे.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation type="unfinished">वॉलेट अनलॉक करा</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation type="unfinished">पासफ़्रेज़ बदला</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation type="unfinished">वॉलेट एन्क्रिप्शनची पुष्टी करा
 </translation>
    </message>
    </context>
<context>
    <name>BitcoinApplication</name>
    <message>
        <source>A fatal error occurred. %1 can no longer continue safely and will quit.</source>
        <translation type="unfinished">एक गंभीर त्रुटी आली. %1यापुढे सुरक्षितपणे सुरू ठेवू शकत नाही आणि संपेल.</translation>
    </message>
    <message>
        <source>Internal error</source>
        <translation type="unfinished">अंतर्गत त्रुटी</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>%1 didn't yet exit safely…</source>
        <translation type="unfinished">%1अजून सुरक्षितपणे बाहेर पडलो नाही...</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished">&amp;मिनीमाइज़</translation>
    </message>
    <message>
        <source>&amp;Options…</source>
        <translation type="unfinished">&amp;पर्याय</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet…</source>
        <translation type="unfinished">&amp;एनक्रिप्ट वॉलेट</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet…</source>
        <translation type="unfinished">&amp;बॅकअप वॉलेट...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase…</source>
        <translation type="unfinished">&amp;पासफ्रेज बदला...</translation>
    </message>
    <message>
        <source>Sign &amp;message…</source>
        <translation type="unfinished">स्वाक्षरी आणि संदेश...</translation>
    </message>
    <message>
        <source>&amp;Verify message…</source>
        <translation type="unfinished">&amp;संदेश सत्यापित करा...</translation>
    </message>
    <message>
        <source>&amp;Load PSBT from file…</source>
        <translation type="unfinished">फाइलमधून PSBT &amp;लोड करा...</translation>
    </message>
    <message>
        <source>Close Wallet…</source>
        <translation type="unfinished">वॉलेट बंद करा...</translation>
    </message>
    <message>
        <source>Create Wallet…</source>
        <translation type="unfinished">वॉलेट तयार करा...</translation>
    </message>
    <message>
        <source>Close All Wallets…</source>
        <translation type="unfinished">सर्व वॉलेट बंद करा...</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)…</source>
        <translation type="unfinished">शीर्षलेख समक्रमित करत आहे (%1%)…</translation>
    </message>
    <message>
        <source>Synchronizing with network…</source>
        <translation type="unfinished">नेटवर्कसह सिंक्रोनाइझ करत आहे...</translation>
    </message>
    <message>
        <source>Indexing blocks on disk…</source>
        <translation type="unfinished">डिस्कवर ब्लॉक अनुक्रमित करत आहे...</translation>
    </message>
    <message>
        <source>Processing blocks on disk…</source>
        <translation type="unfinished">डिस्कवर ब्लॉक्सवर प्रक्रिया करत आहे...</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(लेबल नाही)</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform>(of %n GB needed)</numerusform>
            <numerusform>(of %n GB needed)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform>(%n GB needed for full chain)</numerusform>
            <numerusform>(%n GB needed for full chain)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">पत्ता</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">लेबल</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(लेबल नाही)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(लेबल नाही)</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">लेबल</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(लेबल नाही)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">कॉमा सेपरेटेड फ़ाइल</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">लेबल</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">पत्ता</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">निर्यात अयशस्वी</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;एक्स्पोर्ट</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">सध्याच्या टॅबमधील डेटा एका फाईलमध्ये एक्स्पोर्ट करा</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Settings file could not be read</source>
        <translation type="unfinished">सेटिंग्ज फाइल वाचता आली नाही</translation>
    </message>
    <message>
        <source>Settings file could not be written</source>
        <translation type="unfinished">सेटिंग्ज फाइल लिहिता आली नाही</translation>
    </message>
</context>
</TS>
